<?php
class Form_To_Sheet_Relation{

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;


	// private $google_sheet_func;
	public $teleport;


	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name = "", $version = "", $fts_google_sheet = "" ) {

		$this->plugin_name = $plugin_name;
		$this->version     = $version;
		$this->teleport    = $fts_google_sheet;

		// Adding List table
		require_once plugin_dir_path( dirname( __FILE__ ) ). 'includes/class-form-to-sheet-list-table.php';
	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {
	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		wp_register_script( 'fts_vuejs', plugin_dir_url( __FILE__ ) . 'js/vue.min.js', '', false, false );
		wp_enqueue_script( 'axios', plugin_dir_url( __FILE__ ) . 'js/form_to_sheet_admin.js', array('fts_vuejs'), '', true );
		wp_enqueue_script( 'fts_main_js',plugin_dir_url( __FILE__ ) . 'js/form_to_sheet_admin.js', array( 'fts_vuejs', 'jQuery', 'axios' ), '', true );
	}

	public function fts_action(){

        do_action( 'fts_sheet_columns' );

	}

    public function fts_get_forms() {
        $form_provider    = $_POST['formProviderId'];

        if( $form_provider ) {
            $forms = call_user_func( "ftos_{$form_provider}_get_forms", $form_provider );

            if( !is_wp_error( $forms ) ) {
                wp_send_json_success( $forms );
            }
        }

        exit();
    }

    public function fts_get_form_fields() {
        $form_provider = $_POST['formProviderId'];
        $form_id       = $_POST['formId'];

        if( $form_provider && $form_id ) {
            $fields = call_user_func( "ftos_{$form_provider}_get_form_fields", $form_provider, $form_id );
			$fields["submission_date"] = __( "Submission Date", "form-to-sheet" );
			$fields["user_ip"] = __( "User IP", "form-to-sheet" );

            if( !is_wp_error( $fields ) ) {
                wp_send_json_success( $fields );
            }
        }

        exit();
    }

    public function fts_get_spreadsheets() {
        $spreadsheet_provider_id = $_POST['spreadsheetProviderId'];

        do_action( 'fts_spreadsheets_list', $spreadsheet_provider_id );

        exit();
    }

	public function fts_get_worksheets( ) {

        $spreadsheet_provider_id = $_POST['spreadsheetProviderId'];

        do_action( 'fts_worksheets_list', $spreadsheet_provider_id );

		exit();
	}

    // Main Menu
	public function fts_menu_pages() {
		add_menu_page( __( 'Forms to Sheets', 'form-to-sheet' ), __( 'Forms to Sheets', 'form-to-sheet' ), 'manage_options', 'form-to-sheet', array( $this, 'fts_routing' ), 'dashicons-list-view' );
		add_submenu_page( 'form-to-sheet', __( 'All Mapping', 'form-to-sheet' ), __( 'All Mapping', 'form-to-sheet' ), 'manage_options', 'form-to-sheet', array( $this, 'fts_routing' ) );
		add_submenu_page( 'form-to-sheet', __( 'Add New', 'form-to-sheet' ), __( 'Add New', 'form-to-sheet' ), 'manage_options', 'form-to-sheet-new', array( $this, 'fts_add_new' ) );
	}

	public function fts_routing() {
		$action = isset( $_GET['action'] ) ? $_GET['action'] : 'list';
		$id     = isset( $_GET['id'] ) ? intval( $_GET['id'] ) : 0;
		switch ( $action ) {
		    case 'edit':
		    	$this->fts_edit($id);
		        break;
		    case 'status':
		        $this->fts_change_status($id);
		        break;
		    default:
		        $this->fts_landing_page() ;
		    break;
		}
	}


	public function fts_landing_page() {
		if ( isset( $_GET['status'] ) ) {
			$status = $_GET['status'];
		}

		?>
		<div class="wrap">
		<h1 class="wp-heading-inline">
			<?php _e( 'Mapping', 'form-to-sheet' ); ?>
		</h1>
		<a href="<?php echo admin_url( 'admin.php?page=form-to-sheet-new' ); ?>" class="page-title-action"><?php _e( 'Add New', 'form-to-sheet' ); ?></a>

		<?php

		$list_table = new Form_To_Sheet_List_Table();
		$list_table->prepare_items();
		$list_table->display();

		?>
		</div>
		<?php
	}

	public function fts_add_new(){


        $form_providers        = ftos_get_form_providers();
        $spreadsheet_providers = ftos_get_spreadsheet_providers();

		require_once plugin_dir_path( dirname(__FILE__)) . 'admin/partials/add_new_relation_view.php';
	}

	public function fts_view( $id='' ) {
	}

	public function fts_edit( $id='' ) {

		if ( $id ) {

		    require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/partials/edit_relation_view.php';

		}
	}

	# Relation Status Change fts_status
	public function fts_change_status( $id='' ) {
		echo $id;

		global $wpdb;

		$relation_table = $wpdb->prefix . 'form_to_sheet';
		$status_data    = $wpdb->get_row( "SELECT * FROM " . $relation_table . " WHERE id =" . $id, ARRAY_A );
		$status         = $status_data['status'];

		if ( $status ) {
			$action_status = $wpdb->update( $relation_table,
				array(
		            'status' => false,
				),
				array( 'id'=> $id )
			);
		}else{
			$action_status = $wpdb->update( $relation_table,
				array(
		            'status' => true ,
				),
				array( 'id'=> $id )
			);
		}

        form_to_sheet_redirect( admin_url( 'admin.php?page=form-to-sheet' ) );
	}

	public function fts_save_submitted_relations() {
        do_action( 'fts_save_relations' );
	}

    public function fts_update_relations() {
        do_action( 'fts_update_relations' );
    }
}