<?php
class Form_To_Sheet_Settings {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	# Our Class init
	private $teleport ;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version , $fts_google_sheet ) {

		$this->plugin_name = $plugin_name;
		$this->version     = $version;
		$this->teleport    = $fts_google_sheet;
	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {
		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/form-to-sheet-admin.css', array(), $this->version, 'all' );
	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {
		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/form-to-sheet-admin.js', array( 'jquery' ), $this->version, false );
	}

	// Settings Submenu
	public function fts_submenu_pages( $value = '' ) {
		add_submenu_page( 'form-to-sheet', __( 'Settings ', 'form-to-sheet' ), __( 'Settings', 'form-to-sheet'),'manage_options', 'form-to-sheet-settings', array( $this,'fts_settings') );
	}

	// Settings Submenu View
	public function fts_settings( $value = '' ) {
		$tabs = $this->get_tabs();

		require_once plugin_dir_path(dirname( __FILE__ ) ) . 'admin/partials/settings_view.php';
	}

	public function get_tabs() {
		$tabs = array(
			'gsheet' => __( 'Google Sheets', 'form-to-sheet' )
		);

		return apply_filters( 'fts_settings_tabs', $tabs );
	}
}